@@ -42,7 +42,7 @@ class BaseDictionaryStore(BaseStore):
                      as a timedelta or integer number of seconds
         """
         super(BaseDictionaryStore, self).__init__()
-        self.__keyvalue_helper = KeyValueHelper(polymorphic=polymorphic)
+        self.__keyvalue_helper = KeyValueHelper(verbose=True, polymorphic=polymorphic)
         self.__dictionary = dictionary
         if lifetime_cb:
             self.__lifetime_cb = lifetime_cb
@@ -60,7 +60,7 @@ class BaseDictionaryStore(BaseStore):
             elif isinstance(lifetime, int) or isinstance(lifetime, float):
                 lifetime = datetime.today() + timedelta(seconds=int(lifetime))
         
-        for k in self.__keyvalue_helper.generate_all_verbose_lookup_keys(obj):
+        for k in self.__keyvalue_helper.generate_all_lookup_keys(obj):
             self.__dictionary[k] = (obj, lifetime)
 
     def batch_put(self, objs):
@@ -70,7 +70,7 @@ class BaseDictionaryStore(BaseStore):
     
     def delete(self, obj):
         """deletes an object from the dictionary store"""
-        cachekeys = self.__keyvalue_helper.generate_all_verbose_lookup_keys(obj)
+        cachekeys = self.__keyvalue_helper.generate_all_lookup_keys(obj)
         for k in cachekeys:
             if k in self.__dictionary:
                 del self.__dictionary[k]
@@ -84,7 +84,7 @@ class BaseDictionaryStore(BaseStore):
         """retrieves an object of the given class, under the given 'key' (a dictionary of key/value pairs)
         Expiration is checked before returning the object.  If the object has expired,
         this method will delete the object from the dictionary store."""
-        cachekey = self.__keyvalue_helper.generate_verbose_lookup_key(klass, key)
+        cachekey = self.__keyvalue_helper.generate_lookup_key(klass, key)
         result = self.__dictionary.get(cachekey, None)
         if result:
             (obj, lifetime) = result
