@@ -1,7 +1,8 @@
 import threading
 from stockpyle._base import BaseStore
+from stockpyle.exceptions import NonUniqueKeyError
 try:
-    from sqlalchemy.orm import EXT_CONTINUE, SessionExtension
+    import sqlalchemy
     __HAS_SQLALCHEMY = True
 except ImportError:
     __HAS_SQLALCHEMY = False
@@ -9,6 +10,10 @@ except ImportError:
 
 if __HAS_SQLALCHEMY:
 
+    from sqlalchemy import create_engine
+    from sqlalchemy.orm import sessionmaker, EXT_CONTINUE, SessionExtension
+    from sqlalchemy.exceptions import InvalidRequestError
+
 
     # SQLAlchemy is installed
     class StockpyleSessionExtension(SessionExtension):
@@ -100,7 +105,6 @@ class SqlAlchemyStore(BaseStore):
         else:
             # no session, we have to make one
             # first we need to get the engine
-            from sqlalchemy.orm import sessionmaker
             
             if uri and engine:
                 # can't give two ways to get an engine
@@ -108,7 +112,6 @@ class SqlAlchemyStore(BaseStore):
                 
             elif uri:
                 # we have a uri to create an engine
-                from sqlalchemy import create_engine
                 engine = create_engine(uri)
             
             if engine:
@@ -157,7 +160,6 @@ class SqlAlchemyStore(BaseStore):
             return [None for k in keys]
     
     def _sa_put(self, obj):
-        from sqlalchemy.exceptions import InvalidRequestError
         try:
             self.__session.add(obj)
             self.__session.commit()
@@ -169,9 +171,11 @@ class SqlAlchemyStore(BaseStore):
             except:
                 self.__session.rollback()
                 raise
+        except:
+            self.__session.rollback()
+            raise
 
     def _sa_batch_put(self, objs):
-        from sqlalchemy.exceptions import InvalidRequestError
     
         # commit the session
         try:
@@ -186,9 +190,11 @@ class SqlAlchemyStore(BaseStore):
             except:
                 self.__session.rollback()
                 raise
+        except:
+            self.__session.rollback()
+            raise
     
     def _sa_delete(self, obj):
-        from sqlalchemy.exceptions import InvalidRequestError
         try:
             self.__session.delete(obj)
             self.__session.commit()
@@ -201,9 +207,11 @@ class SqlAlchemyStore(BaseStore):
             except:
                 self.__session.rollback()
                 raise
+        except:
+            self.__session.rollback()
+            raise
     
     def _sa_batch_delete(self, objs):
-        from sqlalchemy.exceptions import InvalidRequestError
 
         # TODO: is there a bulk_delete in SA?
         try:
@@ -220,9 +228,19 @@ class SqlAlchemyStore(BaseStore):
             except:
                 self.__session.rollback()
                 raise
+        except:
+            self.__session.rollback()
+            raise
     
     def _sa_get(self, klass, key):
-        return self.__session.query(klass).filter_by(**key).first()
+        objs = self.__session.query(klass).filter_by(**key)[0:2]
+        if objs:
+            if len(objs) == 2:
+                raise NonUniqueKeyError(klass, key)
+            else:
+                return objs[0]
+        else:
+            return None
     
     def _sa_batch_get(self, klass, keys):
         # FIXME: this is very inefficient, need to read up on the SA API a bit more
